@@ -62,14 +62,16 @@ class AuditTrailMixin:
             app_presentation = app_id  # we don't have any extra information...
 
         user_id = self.request.jwt_auth.payload.get("user_id", "")
+        if not user_id:
+            user_id = get_header(self.request, "X-NLX-Request-User-Id") or ""
+
+        request_id = get_header(self.request, "X-NLX-Request-Id") or ""
 
         toelichting = get_header(self.request, "X-Audit-Toelichting") or ""
 
-        logrecord_id = get_header(self.request, "X-NLX-Logrecord-ID") or ""
-
         trail = AuditTrail(
             bron=self.audit.component_name,
-            logrecord_id=logrecord_id,
+            request_id=request_id,
             applicatie_id=app_id,
             applicatie_weergave=app_presentation,
             actie=action,
@@ -195,11 +197,7 @@ class AuditTrailViewSet(NestedViewSetMixin, viewsets.ReadOnlyModelViewSet):
     main_resource_lookup_field = None  # Must be overwritten by subclasses
 
     def get_queryset(self):
-        if not self.kwargs:  # this happens during schema generation, and causes crashes
-            return self.queryset.all()
-
         qs = super().get_queryset()
-
         identifier = self.kwargs.get(self.main_resource_lookup_field)
         if identifier:
             filtered = qs.filter(hoofd_object__contains=identifier)
@@ -208,9 +206,3 @@ class AuditTrailViewSet(NestedViewSetMixin, viewsets.ReadOnlyModelViewSet):
             else:
                 raise Http404
         return qs
-
-    @property
-    def parent_lookup_kwargs(self):
-        return {
-            self.main_resource_lookup_field: "hoofd_object__contains",
-        }
