@@ -1,12 +1,16 @@
 import logging
 
+from django.conf import settings
+from django.utils.module_loading import import_string
+
 from djangorestframework_camel_case.util import underscoreize
 
 from ..authorizations.models import Applicatie
 from ..authorizations.serializers import ApplicatieUuidSerializer
-from ..client import get_client
 from ..constants import CommonResourceAction
+from ..models import APICredential
 from ..utils import get_uuid_from_path
+from .constants import KANAAL_AUTORISATIES
 
 
 class LoggingHandler:
@@ -17,7 +21,9 @@ class LoggingHandler:
 
 class AuthHandler:
     def _request_auth(self, url: str) -> dict:
-        client = get_client(url)
+        Client = import_string(settings.ZDS_CLIENT_CLASS)
+        client = Client.from_url(url)
+        client.auth = APICredential.get_auth(url)
         response = client.retrieve("applicatie", url)
         return underscoreize(response)
 
@@ -61,4 +67,4 @@ class RoutingHandler:
 log = LoggingHandler()
 auth = AuthHandler()
 
-default = RoutingHandler({"autorisaties": auth}, default=log)
+default = RoutingHandler({KANAAL_AUTORISATIES: auth}, default=log)
